# Funções de auxílio
n_log <- function(name, number, round_coef=2) {
    cat(name, ':', round(number, round_coef), '\n')
}

# Diferença entre médias - Exemplo 1
# Possui o vetor de amostras
# Dados criados artificialmente
set.seed(123091287)

men_data <- rnorm(6, m=117.5, sd=9.7)
women_data <- rnorm(4, m=126.8, sd=12.0)

summary(men_data)
summary(women_data)
n_log('men sd', sd(men_data))
n_log('women sd', sd(women_data))

ans <- var.test(men_data, women_data)

ifelse(ans$p.value < 0.05, 
       is_var_equal <- FALSE, 
       is_var_equal <- TRUE)

(ans <- t.test(men_data, women_data, var.equal=is_var_equal))
n_log('confidence interval', ans$conf.int)

# Não possui o vetor de amostras
# Values
x_bar_1 <- 117.5 # mean(men_data)
x_bar_2 <- 126.8 # mean(women_data)
s_1 <- 9.7 # sd(men_data)
s_2 <- 12.0 # sd(women_data)
n_1 <- 6
n_2 <- 4
alpha <- 0.05

# F test
f_c <- s_1^2 / s_2^2
f_p <- 2 * pf(f_c, df1=n_1 - 1, df2=n_2 - 2)
n_log('f test p-value', f_p)

# t test for variance equality
s_c <- sqrt(((n_1 - 1)*s_1^2 + (n_2 - 1)*s_2^2) / (n_1 + n_2 - 2))
s_combined <- s_c * sqrt((n_1 + n_2) / (n_1 * n_2))

deg_of_freedom <- n_1 + n_2 - 2

critical_t <- qt(alpha / 2, deg_of_freedom, lower.tail=F)
n_log('critical t', critical_t)

me <- critical_t * s_combined
pos_ci <- x_bar_1 - x_bar_2 + me
neg_ci <- x_bar_1 - x_bar_2 - me

ci <- c(neg_ci, pos_ci)

n_log('confidence interval', ci)

# Diferença entre duas proporções - Exemplo 2
frequencies <- c(95, 105)
populations <- c(150, 250)

prop.test(frequencies, populations, correct=FALSE)

# Na unha
# Values
alpha = 0.05
p_1 <- 0.63
p_2 <- 0.42
n_1 <- 150
n_2 <- 250

# z test
sigma_combined <- sqrt((p_1*(1 - p_1)) / n_1 + (p_2*(1 - p_2)) / n_2)
critical_z <- qnorm(alpha / 2, lower.tail=F)
me <- critical_z * sigma_combined
pos_ci <- p_1 - p_2 + me
neg_ci <- p_1 - p_2 - me

ci <- c(neg_ci, pos_ci)

n_log('confidence interval', ci)
